@@ -1,4 +1,4 @@
-from kubernetes.client import V1Event
+from typing import Any
 
 from k8kat.utils.main.types import IntelDict
 
@@ -8,7 +8,7 @@ class KatEvent:
   def __init__(self, raw):
     self.raw = raw
 
-  def body(self) -> V1Event:
+  def body(self) -> Any:
     return self.raw
 
   def intel_bundle(self) -> IntelDict:
