@@ -16,7 +16,14 @@ class KatIngress(KatRes):
   def body(self) -> ExtensionsV1beta1Ingress:
     return self.raw
 
-  def basic_rules(self) -> Dict[str, List[Dict[str, str]]]:
+  def flat_rules(self) -> List[Dict]:
+    as_list = []
+    for host, rules in list(self.basic_rules().items()):
+      for rule in rules:
+        as_list.append({'host': host, **rule})
+    return as_list
+
+  def basic_rules(self) -> Dict[str, List[Dict]]:
     result = {}
     rules: List[ExtensionsV1beta1IngressRule] = self.body().spec.rules
     for rule in rules:
