@@ -104,6 +104,14 @@ def deep_get(dictionary, *keys):
   return reduce(lambda d, key: d.get(key) if d else None, keys, dictionary)
 
 
+def deep_setattr(obj: Any, deep_key: str, value: Any):
+  if '.' not in deep_key:
+    setattr(obj, deep_key, value)
+  else:
+    key_parts = deep_key.split('.')
+    deep_setattr(getattr(obj, key_parts[0]), '.'.join(key_parts[1:]), value)
+
+
 def _deep_merge(dict1, dict2):
   for k in set(dict1.keys()).union(dict2.keys()):
     if k in dict1 and k in dict2:
